==> ssft-0.10.tar.gz: ssft-0.10/XmitBuffer.h <==
/* 
    ssft - is a simple file transfer program that use SSL (Secure 
    Socket Layer) encryption to secure the transfers - and 
    signed certificates to authenticate users and servers. 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Copyright 2001 by Jarle (jgaa) Aase, jgaa@jgaa.com
    http://www.jgaa.com

*/


#ifndef XMIT_BUFFER_H
#define XMIT_BUFFER_H

class XmitBuffer
{
public:
    enum LimitsE
    {
        MAX_BUF_LEN = (1024 * 8)
    };

    XmitBuffer();
    ~XmitBuffer();

    void Reset();

    void AddString(const char *ptr, const size_t len);
    void AddInt32(const int v);
    void AddInt64(const ssft_flen_t& v);

    void GetString(std::string& str);
    void GetInt32(int& v);
    void GetInt64(ssft_flen_t& v);

    size_t GetSize() const;

    char *GetRecvBuffer(size_t size);
    const char *GetSendBuffer(); // GetSize() to get size
    const std::vector<char>& GetSendVector();

private:
    std::vector<char> mBuffer;
    size_t mCurInPos;
    size_t mCurOutPos;

    void Resize(size_t new_chunc);
};

inline XmitBuffer& operator << (XmitBuffer& o, const std::string& v)
{
    o.AddString(v.c_str(), v.size());
    return o;
}

inline XmitBuffer& operator << (XmitBuffer& o, const int v)
{
    o.AddInt32(v);
    return o;
}

inline XmitBuffer& operator << (XmitBuffer& o, const unsigned int v)
{
    o.AddInt32((int)v);
    return o;
}

inline XmitBuffer& operator << (XmitBuffer& o, const ssft_flen_t& v)
{
    o.AddInt64(v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, std::string& v)
{
    o.GetString(v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, int& v)
{
    o.GetInt32(v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, unsigned int& v)
{
    o.GetInt32(*(int *)&v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, ssft_flen_t& v)
{
    o.GetInt64(v);
    return o;
}

#endif

==> ssft-0.12.tar.gz: ssft-0.12/XmitBuffer.h <==
/* 
    ssft - is a simple file transfer program that use SSL (Secure 
    Socket Layer) encryption to secure the transfers - and 
    signed certificates to authenticate users and servers. 

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Copyright 2001 by Jarle (jgaa) Aase, jgaa@jgaa.com
    http://www.jgaa.com

*/


#ifndef XMIT_BUFFER_H
#define XMIT_BUFFER_H

class XmitBuffer
{
public:
    enum LimitsE
    {
        MAX_BUF_LEN = (1024 * 32)
    };

    XmitBuffer();
    ~XmitBuffer();

    void Reset();

    void AddString(const char *ptr, const size_t len) 
        throw(SsftDisconnect);
    void AddInt32(const int v) throw(SsftDisconnect);
    void AddInt64(const ssft_flen_t& v) throw(SsftDisconnect);

    void GetString(std::string& str) throw(SsftDisconnect);
    void GetInt32(int& v) throw(SsftDisconnect);
    void GetInt64(ssft_flen_t& v) throw(SsftDisconnect);

    size_t GetSize() const;
    bool IsAtEndOfOutput() const;

    char *GetRecvBuffer(size_t size) throw(SsftDisconnect);
    const char *GetSendBuffer(); // GetSize() to get size
    const std::vector<char>& GetSendVector();

private:
    std::vector<char> mBuffer;
    size_t mCurInPos;
    size_t mCurOutPos;

    void Resize(size_t new_chunc) throw(SsftDisconnect);
};

inline XmitBuffer& operator << (XmitBuffer& o, const std::string& v)
{
    o.AddString(v.c_str(), v.size());
    return o;
}

inline XmitBuffer& operator << (XmitBuffer& o, const int v)
{
    o.AddInt32(v);
    return o;
}

inline XmitBuffer& operator << (XmitBuffer& o, const unsigned int v)
{
    o.AddInt32((int)v);
    return o;
}

inline XmitBuffer& operator << (XmitBuffer& o, const ssft_flen_t& v)
{
    o.AddInt64(v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, std::string& v)
{
    o.GetString(v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, int& v)
{
    o.GetInt32(v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, unsigned int& v)
{
    o.GetInt32(*(int *)&v);
    return o;
}

inline XmitBuffer& operator >> (XmitBuffer& o, ssft_flen_t& v)
{
    o.GetInt64(v);
    return o;
}

#endif
